==> haskell-pipes-4.3.2-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-pipes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes
version: 4.3.2
id: pipes-4.3.2-LsUxl7vdJuRKCI34rrjNBO
key: pipes-4.3.2-LsUxl7vdJuRKCI34rrjNBO
license: BSD3
copyright: 2012-2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Compositional pipelines
description:
    `pipes` is a clean and powerful stream processing library that lets you build
    and connect reusable streaming components
    .
    Advantages over traditional streaming libraries:
    .
    * /Concise API/: Use simple commands like '\''for'\'', ('\''>->'\''), '\''await'\'', and '\''yield'\''
    .
    * /Blazing fast/: Implementation tuned for speed, including shortcut fusion
    .
    * /Lightweight Dependency/: @pipes@ is small and compiles very rapidly,
    including dependencies
    .
    * /Elegant semantics/: Use practical category theory
    .
    * /ListT/: Correct implementation of '\''ListT'\'' that interconverts with pipes
    .
    * /Bidirectionality/: Implement duplex channels
    .
    * /Extensive Documentation/: Second to none!
    .
    Import "Pipes" to use the library.
    .
    Read "Pipes.Tutorial" for an extensive tutorial.
category: Control, Pipes
author: Gabriel Gonzalez
exposed: True
exposed-modules:
    Pipes Pipes.Core Pipes.Internal Pipes.Lift Pipes.Prelude
    Pipes.Tutorial
abi: 5053abec2c52e426f03513f8a816d58d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/pipes-4.3.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/pipes-4.3.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/pipes-4.3.2
hs-libraries: HSpipes-4.3.2-LsUxl7vdJuRKCI34rrjNBO
depends:
    base-4.9.0.0 exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    mmorph-1.0.9-DmSwQqk5nLj7roLAcydGz mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-pipes/html/pipes.haddock
haddock-html: /usr/share/doc/haskell-pipes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-4.3.3-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-pipes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes
version: 4.3.3
id: pipes-4.3.3-DUMcfIYjM5M3cknwPI4AKY
key: pipes-4.3.3-DUMcfIYjM5M3cknwPI4AKY
license: BSD3
copyright: 2012-2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Compositional pipelines
description:
    `pipes` is a clean and powerful stream processing library that lets you build
    and connect reusable streaming components
    .
    Advantages over traditional streaming libraries:
    .
    * /Concise API/: Use simple commands like '\''for'\'', ('\''>->'\''), '\''await'\'', and '\''yield'\''
    .
    * /Blazing fast/: Implementation tuned for speed, including shortcut fusion
    .
    * /Lightweight Dependency/: @pipes@ is small and compiles very rapidly,
    including dependencies
    .
    * /Elegant semantics/: Use practical category theory
    .
    * /ListT/: Correct implementation of '\''ListT'\'' that interconverts with pipes
    .
    * /Bidirectionality/: Implement duplex channels
    .
    * /Extensive Documentation/: Second to none!
    .
    Import "Pipes" to use the library.
    .
    Read "Pipes.Tutorial" for an extensive tutorial.
category: Control, Pipes
author: Gabriel Gonzalez
exposed: True
exposed-modules:
    Pipes Pipes.Core Pipes.Internal Pipes.Lift Pipes.Prelude
    Pipes.Tutorial
abi: b3c3c5c60b1b6d1023e3e8d1c865f8c6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/pipes-4.3.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/pipes-4.3.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/pipes-4.3.3
hs-libraries: HSpipes-4.3.3-DUMcfIYjM5M3cknwPI4AKY
depends:
    base-4.9.0.0 exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    mmorph-1.0.9-DmSwQqk5nLj7roLAcydGz mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    transformers-0.5.2.0 void-0.7.2-Gq1uNTFl2JaJr51CTc0tGb
haddock-interfaces: /usr/share/doc/haskell-pipes/html/pipes.haddock
haddock-html: /usr/share/doc/haskell-pipes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
